Learn R Programming

tomba (version 1.0.1)

domain_search: Domain search

Description

domain_search Search emails are based on the website You give one domain name and it returns all the email addresses found on the internet.

Usage

domain_search(obj, domain)

# S4 method for Tomba domain_search(obj, domain)

Arguments

obj

Tomba class

domain

Domain name from which you want to find the email addresses. For example, "stripe.com".

Value

A list domain data containing the organization name,country,social links, and list of emails.

References

https://developer.tomba.io/#domain-search

Examples

Run this code
# NOT RUN {
client <- Tomba(key="ta_xxxx",secret="ts_xxxx")
result <- domain_search(obj,domain="stripe")
# }

Run the code above in your browser using DataLab