Learn R Programming

tomba (version 1.0.1)

email_finder: Email Finder

Description

email_finder Generates or retrieves the most likely email address from a domain name, a first name and a last name.

Usage

email_finder(obj, domain, fname, lname)

# S4 method for Tomba email_finder(obj, domain, fname, lname)

Arguments

obj

Tomba class

domain

a character domain name of the company, used for emails. For example, "asana.com".

fname

The person's first name. It doesn't need to be in lowercase..

lname

The person's last name. It doesn't need to be in lowercase..

Value

A list persons data containing the: first_name,last_name,email,score,department,last_updated.

References

https://developer.tomba.io/#email-finder

Examples

Run this code
# NOT RUN {
client <- Tomba(key="ta_xxxx",secret="ts_xxxx")
result <- email_finder(obj,fname="FIRST_NAME",lname="LASST_NAME")
# }

Run the code above in your browser using DataLab