Learn R Programming

tomba (version 1.0.1)

email_sources: Email Sources

Description

email_sources Find email address source somewhere on the web.

Usage

email_sources(obj, email)

# S4 method for Tomba email_sources(obj, email)

Arguments

obj

Tomba class

email

a character email address you want to find sources.

Value

A list sources data data containing the: URL, URL extracted on and last seen on, check if the URL still on page (TRUE|FALSE).

References

https://developer.tomba.io/#email-sources

Examples

Run this code
# NOT RUN {
client <- Tomba(key="ta_xxxx",secret="ts_xxxx")
result <- email_sources(obj,email="info@tomba.io")
# }

Run the code above in your browser using DataLab