powered by
email_sources Find email address source somewhere on the web.
email_sources
email_sources(obj, email)# S4 method for Tomba email_sources(obj, email)
# S4 method for Tomba email_sources(obj, email)
Tomba class
a character email address you want to find sources.
A list sources data data containing the: URL, URL extracted on and last seen on, check if the URL still on page (TRUE|FALSE).
https://developer.tomba.io/#email-sources
# NOT RUN { client <- Tomba(key="ta_xxxx",secret="ts_xxxx") result <- email_sources(obj,email="info@tomba.io") # }
Run the code above in your browser using DataLab